@@ -15,6 +15,7 @@ from ephios.core.views.accounts import (
     ProfileView,
     UserProfileCreateView,
     UserProfileDeleteView,
+    UserProfileDetailView,
     UserProfileListView,
     UserProfileNotificationsView,
     UserProfilePasswordResetView,
@@ -109,7 +110,7 @@ urlpatterns = [
         name="event_bulk_delete",
     ),
     path(
-        "shifts/<int:pk>/signup-action/",
+        "shifts/<int:pk>/signup/",
         LocalUserShiftActionView.as_view(),
         name="signup_action",
     ),
@@ -201,6 +202,11 @@ urlpatterns = [
         UserProfileCreateView.as_view(),
         name="userprofile_create",
     ),
+    path(
+        "users/<int:pk>",
+        UserProfileDetailView.as_view(),
+        name="userprofile_detail",
+    ),
     path(
         "consequences/<int:pk>/edit",
         ConsequenceUpdateView.as_view(),
