@@ -87,9 +87,10 @@ class EventDetailView(CustomPermissionRequiredMixin, CanonicalSlugDetailMixin, D
     permission_required = "core.view_event"
 
     def get_queryset(self):
+        base = Event.objects.all()
         if self.request.user.has_perm("core.add_event"):
-            return Event.all_objects.all()
-        return Event.objects.all()
+            base = Event.all_objects.all()
+        return base.prefetch_related("shifts", "shifts__participations")
 
 
 class EventEditMixin:
@@ -229,7 +230,7 @@ class EventCopyView(CustomPermissionRequiredMixin, SingleObjectMixin, FormView):
         for date in occurrences:
             event = self.get_object()
             start_date = event.get_start_time().date()
-            shifts = event.shifts.all()
+            shifts = list(event.shifts.all())
             event.pk = None
             event.save()
             assign_perm(
@@ -312,6 +313,9 @@ class EventNotificationView(CustomPermissionRequiredMixin, SingleObjectMixin, Fo
     template_name = "core/event_notification.html"
     form_class = EventNotificationForm
 
+    def get_form_kwargs(self):
+        return {**super().get_form_kwargs(), "event": self.object}
+
     def setup(self, request, *args, **kwargs):
         super().setup(request, *args, **kwargs)
         self.object = self.get_object()
