@@ -5,24 +5,21 @@ from itertools import groupby
 from operator import itemgetter
 
 from django import forms
-from django.contrib import messages
 from django.core.exceptions import ValidationError
-from django.shortcuts import redirect
 from django.template.loader import get_template
-from django.urls import reverse
 from django.utils.translation import gettext_lazy as _
-from django.views.generic import FormView
 from django_select2.forms import Select2MultipleWidget
 from dynamic_preferences.registries import global_preferences_registry
 
 from ephios.core.models import AbstractParticipation, Qualification
-from ephios.core.signup import (
-    AbstractParticipant,
-    BaseDispositionParticipationForm,
+from ephios.core.signup.disposition import BaseDispositionParticipationForm
+from ephios.core.signup.methods import (
+    BaseSignupForm,
     BaseSignupMethod,
     BaseSignupView,
-    ParticipationError,
+    ParticipantUnfitError,
 )
+from ephios.core.signup.participants import AbstractParticipant
 
 NO_SECTION_UUID = "other"
 
@@ -37,7 +34,7 @@ def sections_participant_qualifies_for(sections, participant: AbstractParticipan
 
 
 class SectionBasedDispositionParticipationForm(BaseDispositionParticipationForm):
-    disposition_participation_template = "basesignup/section_based/fragment_participant.html"
+    disposition_participation_template = "basesignup/section_based/fragment_participation.html"
 
     section = forms.ChoiceField(
         label=_("Section"),
@@ -119,7 +116,20 @@ SectionsFormset = forms.formset_factory(
 )
 
 
-class SectionBasedConfigurationForm(forms.Form):
+class SectionBasedConfigurationForm(BaseSignupMethod.configuration_form_class):
+    choose_preferred_section = forms.BooleanField(
+        label=_("Participants must provide a preferred section"),
+        help_text=_("This only makes sense if you configure multiple sections."),
+        widget=forms.CheckboxInput,
+        required=False,
+        initial=False,
+    )
+    sections = forms.Field(
+        label=_("Structure"),
+        widget=forms.HiddenInput,
+        required=False,
+    )
+
     def __init__(self, data=None, **kwargs):
         super().__init__(data, **kwargs)
         self.sections_formset = SectionsFormset(
@@ -142,18 +152,45 @@ class SectionBasedConfigurationForm(forms.Form):
         ]
         return sections
 
+    @staticmethod
+    def format_sections(value):
+        return ", ".join(section["title"] for section in value)
 
-class SectionSignupForm(forms.Form):
-    section = forms.ChoiceField(
+
+class SectionSignupForm(BaseSignupForm):
+    preferred_section_uuid = forms.ChoiceField(
         label=_("Preferred Section"),
         widget=forms.RadioSelect,
         required=False,
-        # choices are set as (uuid, title) of section
+        # choices are later set as (uuid, title) of section
     )
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.fields["preferred_section_uuid"].initial = self.instance.data.get(
+            "preferred_section_uuid"
+        )
+        self.fields["preferred_section_uuid"].required = (
+            self.data.get("signup_choice") == "sign_up"
+            and self.method.configuration.choose_preferred_section
+        )
+        self.fields["preferred_section_uuid"].choices = [
+            (section["uuid"], section["title"])
+            for section in self.sections_participant_qualifies_for
+        ]
+        unqualified = [
+            section
+            for section in self.method.configuration.sections
+            if section not in self.sections_participant_qualifies_for
+        ]
+        if unqualified:
+            self.fields["preferred_section_uuid"].help_text = _(
+                "You don't qualify for {qualifications}."
+            ).format(qualifications=", ".join(str(section["title"]) for section in unqualified))
 
-class SectionBasedSignupView(FormView, BaseSignupView):
-    template_name = "basesignup/section_based/signup.html"
+    def save(self, commit=True):
+        self.instance.data["preferred_section_uuid"] = self.cleaned_data["preferred_section_uuid"]
+        return super().save(commit)
 
     @cached_property
     def sections_participant_qualifies_for(self):
@@ -161,41 +198,9 @@ class SectionBasedSignupView(FormView, BaseSignupView):
             self.method.configuration.sections, self.participant
         )
 
-    def get_form(self, form_class=None):
-        form = SectionSignupForm(self.request.POST)
-        form.fields["section"].choices = [
-            (section["uuid"], section["title"])
-            for section in self.sections_participant_qualifies_for
-        ]
-        return form
 
-    def get_context_data(self, **kwargs):
-        kwargs.setdefault("shift", self.shift)
-        kwargs.setdefault(
-            "unqualified_sections",
-            [
-                section["title"]
-                for section in self.method.configuration.sections
-                if section not in self.sections_participant_qualifies_for
-            ],
-        )
-        return super().get_context_data(**kwargs)
-
-    def form_valid(self, form):
-        return super().signup_pressed(preferred_section_uuid=form.cleaned_data.get("section"))
-
-    def signup_pressed(self, **kwargs):
-        if not self.method.configuration.choose_preferred_section:
-            # do straight signup if choosing is not enabled
-            return super().signup_pressed(**kwargs)
-
-        if not self.method.can_sign_up(self.participant):
-            # redirect a misled request
-            messages.warning(self.request, _("You can not sign up for this shift."))
-            return redirect(self.participant.reverse_event_detail(self.shift.event))
-
-        # all good, redirect to the form
-        return redirect(self.participant.reverse_signup_action(self.shift))
+class SectionBasedSignupView(BaseSignupView):
+    form_class = SectionSignupForm
 
 
 class SectionBasedSignupMethod(BaseSignupMethod):
@@ -208,33 +213,11 @@ class SectionBasedSignupMethod(BaseSignupMethod):
     registration_button_text = _("Request")
     signup_success_message = _("You have successfully requested a participation for {shift}.")
     signup_error_message = _("Requesting a participation failed: {error}")
-
-    configuration_form_class = SectionBasedConfigurationForm
     signup_view_class = SectionBasedSignupView
-
     disposition_participation_form_class = SectionBasedDispositionParticipationForm
 
-    def get_configuration_fields(self):
-        return {
-            **super().get_configuration_fields(),
-            "choose_preferred_section": {
-                "formfield": forms.BooleanField(
-                    label=_("Ask participants for a preferred section"),
-                    help_text=_("This only makes sense if you configure multiple sections."),
-                    widget=forms.CheckboxInput,
-                    required=False,
-                ),
-                "default": False,
-            },
-            "sections": {
-                "formfield": forms.Field(
-                    label=_("Structure"),
-                    widget=forms.HiddenInput,
-                    required=False,
-                ),
-                "default": [],
-            },
-        }
+    configuration_form_class = SectionBasedConfigurationForm
+    shift_state_template_name = "basesignup/section_based/fragment_state.html"
 
     def _get_signup_stats_per_section(self, participations=None):
         from ephios.core.signup.methods import SignupStats
@@ -299,7 +282,7 @@ class SectionBasedSignupMethod(BaseSignupMethod):
     @staticmethod
     def check_qualification(method, participant):
         if not sections_participant_qualifies_for(method.configuration.sections, participant):
-            return ParticipationError(_("You are not qualified."))
+            return ParticipantUnfitError(_("You are not qualified."))
 
     @property
     def _signup_checkers(self):
@@ -307,31 +290,22 @@ class SectionBasedSignupMethod(BaseSignupMethod):
 
     # pylint: disable=arguments-differ
     def _configure_participation(
-        self, participation: AbstractParticipation, preferred_section_uuid=None, **kwargs
+        self, participation: AbstractParticipation, **kwargs
     ) -> AbstractParticipation:
-        participation.data["preferred_section_uuid"] = preferred_section_uuid
-        if preferred_section_uuid:
-            # reset dispatch decision, as that would have overwritten the preferred choice
-            participation.data["dispatched_section_uuid"] = None
         participation.state = AbstractParticipation.States.REQUESTED
         return participation
 
     def render_configuration_form(self, *args, form=None, **kwargs):
+        """We overwrite the template to render the formset."""
         form = form or self.get_configuration_form(*args, **kwargs)
         template = get_template("basesignup/section_based/configuration_form.html").render(
             {"form": form}
         )
         return template
 
-    def render_shift_state(self, request):
-
-        participations = self.shift.participations.filter(
-            state__in={
-                AbstractParticipation.States.REQUESTED,
-                AbstractParticipation.States.CONFIRMED,
-            }
-        ).order_by("-state")
-
+    def get_shift_state_context_data(self, request, **kwargs):
+        context_data = super().get_shift_state_context_data(request)
+        participations = context_data["participations"]
         section_stats = self._get_signup_stats_per_section(participations)
         sections = {
             section["uuid"]: {
@@ -367,20 +341,8 @@ class SectionBasedSignupMethod(BaseSignupMethod):
                 "placeholder": [],
             }
 
-        return get_template("basesignup/section_based/fragment_state.html").render(
-            {
-                "shift": self.shift,
-                "sections": sections,
-                "disposition_url": (
-                    reverse(
-                        "core:shift_disposition",
-                        kwargs=dict(pk=self.shift.pk),
-                    )
-                    if request.user.has_perm("core.change_event", obj=self.shift.event)
-                    else None
-                ),
-            }
-        )
+        context_data["sections"] = sections
+        return context_data
 
     def _get_sections_with_users(self):
         relevant_qualification_categories = global_preferences_registry.manager()[
