@@ -25,9 +25,6 @@ if not os.path.exists(DATA_DIR):
 SECRET_KEY = env.str("SECRET_KEY")
 DEBUG = env.bool("DEBUG")
 ALLOWED_HOSTS = env.list("ALLOWED_HOSTS")
-SITE_URL = env.str("SITE_URL")
-if SITE_URL.endswith("/"):
-    SITE_URL = SITE_URL[:-1]
 
 if not DEBUG:
     SESSION_COOKIE_SECURE = True
@@ -277,3 +274,10 @@ if vapid_private_key_path := env.str("VAPID_PRIVATE_KEY_PATH", None):
         "VAPID_PRIVATE_KEY": vp,
         "VAPID_ADMIN_EMAIL": ADMINS[0][1],
     }
+
+
+def GET_SITE_URL():
+    site_url = env.str("SITE_URL")
+    if site_url.endswith("/"):
+        site_url = site_url[:-1]
+    return site_url
